<?php

return [
    'Names' => [
        'aa' => 'အာဖာ',
        'ab' => 'အဘ်ခါဇီရာ',
        'ace' => 'အာချေး',
        'ada' => 'ဒန်မဲ',
        'ady' => 'အဒိုင်ဂီ',
        'af' => 'အာဖရိကန်',
        'agq' => 'အာဂ်ဟိန်း',
        'ain' => 'အိန်နု',
        'ak' => 'အာကန်',
        'ale' => 'အာလီယု',
        'alt' => 'တောင် အာလ်တိုင်း',
        'am' => 'အမ်ဟာရစ်ခ်',
        'an' => 'အာရာဂွန်',
        'ang' => 'အင်ဂလို ဆက္ကစွန်',
        'ann' => 'အိုဘိုလို',
        'anp' => 'အန်ဂီကာ',
        'ar' => 'အာရဗီ',
        'arn' => 'မာပုချီ',
        'arp' => 'အာရာပါဟို',
        'ars' => 'နာ့ဂျဒီ အာရဗစ်',
        'as' => 'အာသံ',
        'asa' => 'အာစု',
        'ast' => 'အက်စ်တိုးရီးယား',
        'atj' => 'အာတီကမဲကု',
        'av' => 'အာဗာရစ်ခ်',
        'awa' => 'အာဝါဒီ',
        'ay' => 'အိုင်မာရ',
        'az' => 'အဇာဘိုင်ဂျန်',
        'ba' => 'ဘက်ရှ်ကာ',
        'ban' => 'ဘာလီ',
        'bas' => 'ဘာဆာ',
        'be' => 'ဘီလာရုစ်',
        'bem' => 'ဘိန်ဘာ',
        'bez' => 'ဘီနာ',
        'bg' => 'ဘူလ်ဂေးရီးယား',
        'bgn' => 'အနောက် ဘဲလိုချီ',
        'bho' => 'ဘို့ဂျ်ပူရီ',
        'bi' => 'ဘစ်စ်လာမာ',
        'bin' => 'ဘီနီ',
        'bla' => 'စစ္စီကာ',
        'bm' => 'ဘန်ဘာရာ',
        'bn' => 'ဘင်္ဂါလီ',
        'bo' => 'တိဘက်',
        'br' => 'ဘရီတွန်',
        'brx' => 'ဗိုဒို',
        'bs' => 'ဘော့စ်နီးယား',
        'bug' => 'ဘူဂစ်စ်',
        'byn' => 'ဘလင်',
        'ca' => 'ကတ်တလန်',
        'cay' => 'ကာယုဂါ',
        'ccp' => 'ချတ်ခ်မာ',
        'ce' => 'ချက်ချန်း',
        'ceb' => 'စီဗူအာနို',
        'cgg' => 'ချီဂါ',
        'ch' => 'ချမိုရို',
        'chk' => 'ချူကီးစ်',
        'chm' => 'မာရီ',
        'cho' => 'ချော့တို',
        'chp' => 'ချီပွေဝိုင်ရန်',
        'chr' => 'ချာရိုကီ',
        'chy' => 'ချေယန်း',
        'ckb' => 'ဗဟိုဒေသသုံး ကဒ်ဘာသာ',
        'clc' => 'ချီကိုလ်တင်',
        'co' => 'ခိုစီကန်',
        'cr' => 'ခရီး',
        'crg' => 'မစ်ချစ်ခ်',
        'crj' => 'တောင်ပိုင်း အရှေ့ခရီ',
        'crk' => 'ပလိန်းစ် ခရီ',
        'crl' => 'မြောက်ပိုင်း အရှေ့ခရီ',
        'crm' => 'မုစ်ခရီး',
        'crr' => 'ကယ်ရိုလိုင်းနား အယ်လ်ဂွန်းကီယန်',
        'crs' => 'ခရီအိုလီ',
        'cs' => 'ချက်',
        'csw' => 'ဆွမ်ပီ ခရီ',
        'cu' => 'ချပ်ချ် စလာဗစ်',
        'cv' => 'ချူဗက်ရှ်',
        'cy' => 'ဝေလ',
        'da' => 'ဒိန်းမတ်',
        'dak' => 'ဒါကိုတာ',
        'dar' => 'ဒါဂ်ဝါ',
        'dav' => 'တိုင်တာ',
        'de' => 'ဂျာမန်',
        'del' => 'ဒယ်လာဝဲလ်',
        'dgr' => 'ဒေါ့ဂ်ရစ်ဘ်',
        'dje' => 'ဇာမာ',
        'doi' => 'ဒိုဂရီ',
        'dsb' => 'အနိမ့် ဆိုဘီယန်း',
        'dua' => 'ဒူအလာ',
        'dum' => 'အလယ်ပိုင်း ဒတ်ချ်',
        'dv' => 'ဒီဗာဟီ',
        'dyo' => 'ဂျိုလာ-ဖွန်ရီ',
        'dz' => 'ဒဇွန်ကာ',
        'dzg' => 'ဒဇာဂါ',
        'ebu' => 'အမ်ဘူ',
        'ee' => 'အီဝီ',
        'efi' => 'အာဖိခ်',
        'egy' => 'ရှေးဟောင်း အီဂျစ်',
        'eka' => 'အီကာဂျုခ်',
        'el' => 'ဂရိ',
        'en' => 'အင်္ဂလိပ်',
        'enm' => 'အလယ်ပိုင်း အင်္ဂလိပ်',
        'eo' => 'အက်စ်ပရန်တို',
        'es' => 'စပိန်',
        'et' => 'အက်စ်တိုးနီးယား',
        'eu' => 'ဘာစ်ခ်',
        'ewo' => 'အီဝန်ဒို',
        'fa' => 'ပါရှန်',
        'ff' => 'ဖူလာ',
        'fi' => 'ဖင်လန်',
        'fil' => 'ဖိလစ်ပိုင်',
        'fj' => 'ဖီဂျီ',
        'fo' => 'ဖာရို',
        'fon' => 'ဖော်န်',
        'fr' => 'ပြင်သစ်',
        'frc' => 'ကေဂျန် ဖရန့်စ်',
        'frm' => 'အလယ်ပိုင်း ပြင်သစ်',
        'fro' => 'ဖရန်စီစ်',
        'frr' => 'မြောက် ဖရီစီရန်',
        'frs' => 'အရှေ့ ဖရီစီရန်',
        'fur' => 'ဖရူလီယန်း',
        'fy' => 'အနောက် ဖရီစီရန်',
        'ga' => 'အိုင်းရစ်ရှ်',
        'gaa' => 'ဂါ',
        'gag' => 'ဂါဂုဇ်',
        'gd' => 'စကော့တစ်ရှ် ဂေးလစ်ခ်',
        'gez' => 'ဂီးဇ်',
        'gil' => 'ကာရီဗာတီ',
        'gl' => 'ဂါလီစီယာ',
        'gmh' => 'အလယ်ပိုင်း အမြင့် ဂျာမန်',
        'gn' => 'ဂူအာရာနီ',
        'gor' => 'ဂိုရိုတာလို',
        'grc' => 'ရှေးဟောင်း ဂရိ',
        'gsw' => 'ဆွစ် ဂျာမန်',
        'gu' => 'ဂူဂျာရသီ',
        'guz' => 'ဂူစီး',
        'gv' => 'မန်းဇ်',
        'gwi' => 'ဂွစ်ချင်',
        'ha' => 'ဟာဥစာ',
        'hai' => 'ဟေဒါ',
        'haw' => 'ဟာဝိုင်ယီ',
        'hax' => 'တောင် ဟိုင်ဒါ',
        'he' => 'ဟီဘရူး',
        'hi' => 'ဟိန်ဒူ',
        'hil' => 'ဟီလီဂေနွန်',
        'hmn' => 'မုံ',
        'hr' => 'ခရိုအေးရှား',
        'hsb' => 'ဆက္ကဆိုနီ',
        'ht' => 'ဟေတီ',
        'hu' => 'ဟန်ဂေရီ',
        'hup' => 'ဟူပါ',
        'hur' => 'ဟော့ကမိုလွမ်',
        'hy' => 'အာမေးနီးယား',
        'hz' => 'ဟီရဲရို',
        'ia' => 'အင်တာလင်ဂွါ',
        'iba' => 'အီဗန်',
        'ibb' => 'အီဘီဘီယို',
        'id' => 'အင်ဒိုနီးရှား',
        'ig' => 'အစ္ဂဘို',
        'ii' => 'စီချွမ် ရီ',
        'ikt' => 'အနောက် ကနေဒီယန် အီနုတီတွတ်',
        'ilo' => 'အီလိုကို',
        'inh' => 'အင်ဂုရှ်',
        'io' => 'အီဒို',
        'is' => 'အိုက်စ်လန်',
        'it' => 'အီတလီ',
        'iu' => 'အီနုခ်တီတု',
        'ja' => 'ဂျပန်',
        'jbo' => 'လိုဂျ်ဘန်',
        'jgo' => 'ဂွမ်ဘာ',
        'jmc' => 'မချာမီ',
        'jpr' => 'ဂျူဒီယို-ပါရှန်',
        'jrb' => 'ဂျူဒီယို-အာရဗီ',
        'jv' => 'ဂျာဗား',
        'ka' => 'ဂျော်ဂျီယာ',
        'kab' => 'ကဘိုင်လ်',
        'kac' => 'ကချင်',
        'kaj' => 'ဂျူအူ',
        'kam' => 'ကမ်ဘာ',
        'kbd' => 'ကဘာဒင်',
        'kcg' => 'တိုင်အပ်',
        'kde' => 'မာခွန်ဒီ',
        'kea' => 'ကဘူဗာဒီအာနူ',
        'kfo' => 'ကိုရို',
        'kg' => 'ကွန်ဂို',
        'kgp' => 'ကိန်းဂန်',
        'kha' => 'ခါစီ',
        'khq' => 'ကိုရာ ချီအီနီ',
        'ki' => 'ကီကူယူ',
        'kj' => 'ကွန်းယာမာ',
        'kk' => 'ကာဇာချ',
        'kkj' => 'ကကို',
        'kl' => 'ကလာအ်လီဆပ်',
        'kln' => 'ကလန်ဂျင်',
        'km' => 'ခမာ',
        'kmb' => 'ကင်ဘွန်ဒူ',
        'kn' => 'ကန်နာဒါ',
        'ko' => 'ကိုရီးယား',
        'koi' => 'ကိုမီ-ပါမြက်',
        'kok' => 'ကွန်ကနီ',
        'kpe' => 'ကပ်ပဲလ်',
        'kr' => 'ကနူရီ',
        'krc' => 'ကရာချေး-ဘာကာ',
        'krl' => 'ကာရီလီယန်',
        'kru' => 'ကူရုပ်ခ်',
        'ks' => 'ကက်ရှ်မီးယား',
        'ksb' => 'ရှန်ဘာလာ',
        'ksf' => 'ဘာဖီအာ',
        'ksh' => 'ကိုလိုနီယန်း',
        'ku' => 'ကဒ်',
        'kum' => 'ကွမ်မိုက်',
        'kv' => 'ကိုမီ',
        'kw' => 'ခိုနီရှ်',
        'kwk' => 'ကွပ်ခ်ဝါလာ',
        'ky' => 'ကာဂျစ်',
        'la' => 'လက်တင်',
        'lad' => 'လာဒီနို',
        'lag' => 'လန်ဂီ',
        'lb' => 'လူဇင်ဘတ်',
        'lez' => 'လက်ဇ်ဂီးယား',
        'lg' => 'ဂန်ဒါ',
        'li' => 'လင်ဘာဂစ်ရှ်',
        'lil' => 'လာလူးဝစ်တ်',
        'lkt' => 'လာကိုတာ',
        'ln' => 'လင်ဂါလာ',
        'lo' => 'လာအို',
        'lou' => 'လူဝီဇီယားနား ခရီးယို',
        'loz' => 'လိုဇီ',
        'lrc' => 'မြောက်လူရီ',
        'lsm' => 'ဆာမိအာ',
        'lt' => 'လစ်သူဝေးနီးယား',
        'lu' => 'လူဘာ-ကတန်ဂါ',
        'lua' => 'လူဘာ-လူလူအာ',
        'lun' => 'လွန်ဒါ',
        'luo' => 'လူအို',
        'lus' => 'မီဇို',
        'luy' => 'လူရီအာ',
        'lv' => 'လတ်ဗီးယား',
        'mad' => 'မဒူရာ',
        'mag' => 'မဂါဟီ',
        'mai' => 'မိုင်သီလီ',
        'mak' => 'မကာဆာ',
        'mas' => 'မာဆိုင်',
        'mdf' => 'မို့ခ်ရှာ',
        'men' => 'မန်ဒဲ',
        'mer' => 'မီရု',
        'mfe' => 'မောရစ်ရှ',
        'mg' => 'မာလဂက်စီ',
        'mga' => 'အလယ်ပိုင်း အိုင်းရစ်ရှ်',
        'mgh' => 'မာခူဝါ-မီအီတို',
        'mgo' => 'မီတာ',
        'mh' => 'မာရှယ်လိဇ်',
        'mi' => 'မာအိုရီ',
        'mic' => 'မစ်ခ်မက်ခ်',
        'min' => 'စူကူမီနန်',
        'mk' => 'မက်ဆီဒိုးနီးယား',
        'ml' => 'မလေယာလမ်',
        'mn' => 'မွန်ဂိုလီးယား',
        'mnc' => 'မန်ချူး',
        'mni' => 'မနိပူရ',
        'moe' => 'အီနုအေမွန်',
        'moh' => 'မိုဟော့ခ်',
        'mos' => 'မိုစီ',
        'mr' => 'မာရသီ',
        'ms' => 'မလေး',
        'mt' => 'မော်လ်တာ',
        'mua' => 'မွန်ဒန်း',
        'mus' => 'ခရိချ',
        'mwl' => 'မီရန်ဒီးဇ်',
        'my' => 'မြန်မာ',
        'myv' => 'အီဇယာ',
        'mzn' => 'မာဇန်ဒါရန်နီ',
        'na' => 'နော်ရူး',
        'nap' => 'နပိုလီတန်',
        'naq' => 'နာမာ',
        'nb' => 'နော်ဝေ ဘွတ်ခ်မော်လ်',
        'nd' => 'မြောက် အွန်န်ဒီဘီလီ',
        'nds' => 'အနိမ့် ဂျာမန်',
        'ne' => 'နီပေါ',
        'new' => 'နီဝါရီ',
        'ng' => 'အွန်ဒွန်ဂါ',
        'nia' => 'နီးရပ်စ်',
        'niu' => 'နူအဲယန်း',
        'nl' => 'ဒတ်ခ်ျ',
        'nmg' => 'ကွာစီအို',
        'nn' => 'နော်ဝေ နီးနောစ်',
        'nnh' => 'အွန်ရဲဘွန်း',
        'no' => 'နော်ဝေ',
        'nog' => 'နိုဂိုင်',
        'nqo' => 'အွန်ကို',
        'nr' => 'တောင် အွန်န်ဘီလီ',
        'nso' => 'မြောက် ဆိုသို',
        'nus' => 'နူအာ',
        'nv' => 'နာဗာဟို',
        'ny' => 'နရန်ဂျာ',
        'nyn' => 'နရန်ကိုလီ',
        'oc' => 'အိုစီတန်',
        'ojb' => 'အိုဂျစ်ဘွာ',
        'ojc' => 'အိုဂျစ်ဘွေး',
        'ojs' => 'အိုဂျီခရီ',
        'ojw' => 'အနောက် အိုဂျီဘွာ',
        'oka' => 'အိုကနဂန်',
        'om' => 'အိုရိုမို',
        'or' => 'အိုရီရာ',
        'os' => 'အိုဆဲတစ်ခ်',
        'pa' => 'ပန်ချာပီ',
        'pag' => 'ပန်ဂါစီနန်',
        'pam' => 'ပမ်ပန်ညာ',
        'pap' => 'ပါပီမင်တို',
        'pau' => 'ပလာအို',
        'pcm' => 'နိုင်ဂျီးရီးယား ပစ်ဂျင်',
        'peo' => 'ပါရှန် အဟောင်း',
        'pi' => 'ပါဠိ',
        'pis' => 'ပီဂျင်',
        'pl' => 'ပိုလန်',
        'pqm' => 'မလိဇိ ပါစမ်မကွာဒီ',
        'prg' => 'ပရူရှန်',
        'ps' => 'ပက်ရှ်တွန်း',
        'pt' => 'ပေါ်တူဂီ',
        'qu' => 'ခီချူဝါအိုဝါ',
        'quc' => 'ကီခ်အီချီ',
        'rap' => 'ရပန်နူအီ',
        'rar' => 'ရရိုတွန်ဂန်',
        'rhg' => 'ရိုဟင်ဂျာ',
        'rm' => 'ရောမ',
        'rn' => 'ရွန်ဒီ',
        'ro' => 'ရိုမေနီယား',
        'rof' => 'ရွမ်ဘို',
        'ru' => 'ရုရှ',
        'rup' => 'အာရိုမန်းနီးယန်း',
        'rw' => 'ကင်ရာဝန်ဒါ',
        'rwk' => 'ရူဝမ်',
        'sa' => 'သင်္သကရိုက်',
        'sad' => 'ဆန်ဒါဝီ',
        'sah' => 'ဆခါ',
        'saq' => 'ဆမ်ဘူရူ',
        'sat' => 'ဆန်တာလီ',
        'sba' => 'အွန်ဂမ်းဘေး',
        'sbp' => 'ဆန်ဂု',
        'sc' => 'ဆာဒီနီးယား',
        'scn' => 'စစ္စလီ',
        'sco' => 'စကော့တ်',
        'sd' => 'စင်ဒီ',
        'se' => 'မြောက် ဆာမိ',
        'seh' => 'စီနာ',
        'ses' => 'ကိုရာဘိုရို ဆမ်နီ',
        'sg' => 'ဆန်ဂို',
        'sga' => 'အိုင်းရစ် ဟောင်း',
        'shi' => 'တာချယ်လ်ဟစ်',
        'shn' => 'ရှမ်း',
        'si' => 'စင်ဟာလာ',
        'sk' => 'ဆလိုဗက်',
        'sl' => 'ဆလိုဗေးနီးယား',
        'slh' => 'တောင် လာ့ရှုစတိ',
        'sm' => 'ဆမိုအာ',
        'sma' => 'တောင် ဆာမိ',
        'smj' => 'လူလီ ဆာမိ',
        'smn' => 'အီနာရီ ဆာမိ',
        'sms' => 'စခိုးလ် ဆာမိ',
        'sn' => 'ရှိုနာ',
        'snk' => 'ဆိုနင်ကေး',
        'so' => 'ဆိုမာလီ',
        'sq' => 'အယ်လ်ဘေးနီးယား',
        'sr' => 'ဆားဘီးယား',
        'srn' => 'ဆရာနန် တွန်ဂို',
        'ss' => 'ဆွာဇီလန်',
        'ssy' => 'ဆာဟို',
        'st' => 'တောင်ပိုင်း ဆိုသို',
        'str' => 'ဆဲလစ်ရှ် ရေလက်ကြား',
        'su' => 'ဆူဒန်',
        'suk' => 'ဆူကူမာ',
        'sv' => 'ဆွီဒင်',
        'sw' => 'ဆွာဟီလီ',
        'swb' => 'ကိုမိုရီးယန်း',
        'syr' => 'ဆီးရီးယား',
        'ta' => 'တမီးလ်',
        'tce' => 'တောင် တပ်ချွန်',
        'te' => 'တီလီဂူ',
        'tem' => 'တင်မ်နဲ',
        'teo' => 'တီဆို',
        'tet' => 'တီတွမ်',
        'tg' => 'တာဂျစ်',
        'tgx' => 'တာဂစ်ရှ်',
        'th' => 'ထိုင်း',
        'tht' => 'တဟီတန်',
        'ti' => 'တီဂ်ရင်ယာ',
        'tig' => 'တီဂရီ',
        'tk' => 'တာ့ခ်မင်နစ္စတန်',
        'tlh' => 'ကလင်ဂွန်',
        'tli' => 'တလင်းဂစ်',
        'tn' => 'တီဆဝါနာ',
        'to' => 'တွန်ဂါ',
        'tok' => 'တိုကီပိုနာ',
        'tpi' => 'တော့ခ် ပိစင်',
        'tr' => 'တူရကီ',
        'trv' => 'တရိုကို',
        'ts' => 'ဆွန်ဂါ',
        'tt' => 'တာတာ',
        'ttm' => 'မြောက် တပ်ချွန်',
        'tum' => 'တမ်ဘူကာ',
        'tvl' => 'တူဗာလူ',
        'twq' => 'တာဆာဝါချ',
        'ty' => 'တဟီတီ',
        'tyv' => 'တူဗန်',
        'tzm' => 'အလယ်အာ့တလာစ် တာမာဇိုက်',
        'udm' => 'အူမူရတ်',
        'ug' => 'ဝီဂါ',
        'uk' => 'ယူကရိန်း',
        'umb' => 'အူဘန်ဒူ',
        'ur' => 'အူရ်ဒူ',
        'uz' => 'ဥဇဘတ်',
        'vai' => 'ဗိုင်',
        've' => 'ဗင်န်ဒါ',
        'vi' => 'ဗီယက်နမ်',
        'vo' => 'ဗိုလာပိုက်',
        'vun' => 'ဗွန်ဂျို',
        'wa' => 'ဝါလူးန်',
        'wae' => 'ဝေါလ်ဆာ',
        'wal' => 'ဝိုလက်တာ',
        'war' => 'ဝါရေး',
        'wbp' => 'ဝေါလ်ပီရီ',
        'wo' => 'ဝူလိုဖ်',
        'wuu' => 'ဝူ တရုတ်',
        'xal' => 'ကာလ်မိုက်',
        'xh' => 'ဇိုစာ',
        'xog' => 'ဆိုဂါ',
        'yav' => 'ရန်ဘဲန်',
        'ybb' => 'ရမ်ဘာ',
        'yi' => 'ရဟူဒီ',
        'yo' => 'ယိုရူဘာ',
        'yrl' => 'အန်ဟင်းဂတူ',
        'yue' => 'ကွမ်းတုံ',
        'zgh' => 'မိုရိုကို တမဇိုက်',
        'zh' => 'တရုတ်',
        'zu' => 'ဇူးလူး',
        'zun' => 'ဇူနီ',
        'zza' => 'ဇာဇာ',
    ],
    'LocalizedNames' => [
        'ar_001' => 'ခေတ်သစ် ရှေ့ဆောင် အာရဗီ',
        'de_AT' => 'ဩစတြီးယား ဂျာမန်',
        'de_CH' => 'အလီမဲန်နစ် ဂျာမန်',
        'en_AU' => 'ဩစတြေးလျ အင်္ဂလိပ်',
        'en_CA' => 'ကနေဒါ အင်္ဂလိပ်',
        'en_GB' => 'ဗြိတိသျှ အင်္ဂလိပ်',
        'en_US' => 'အမေရိကန် အင်္ဂလိပ်',
        'es_ES' => 'စပိန် (ဥရောပ)',
        'es_MX' => 'စပိန် (မက္ကဆီကို)',
        'fa_AF' => 'ဒါရီ',
        'fr_CA' => 'ကနေဒါ ပြင်သစ်',
        'fr_CH' => 'ဆွစ် ပြင်သစ်',
        'nds_NL' => 'ဂျာမန် (နယ်သာလန်)',
        'nl_BE' => 'ဖလီမစ်ရှ်',
        'pt_BR' => 'ဘရာဇီး ပေါ်တူဂီ',
        'pt_PT' => 'ဥရောပ ပေါ်တူဂီ',
        'ro_MD' => 'မော်လဒိုဗာ',
        'sw_CD' => 'ကွန်ဂို ဆွာဟီလီ',
    ],
];
